︠57554b1f-7942-40d2-b975-b7d2bad99a5bi︠
%md
###MIWsim1D###

- using lsode with Jacobian

Author: D Cyganski and Bill Page

Created: 2015-05-17

Revised: 2015-06-08
︡6a107ae3-0ab0-497d-b16f-80de2d8ec64b︡{"md":"###MIWsim1D###\n\n- using lsode with Jacobian\n\nAuthor: D Cyganski and Bill Page\n\nCreated: 2015-05-17\n\nRevised: 2015-06-08"}︡
︠54ca014c-bce4-47db-900a-87fe189d4a89i︠
%md
####Implementation of Wiseman Many-Interacting-Worlds simulation for 1D, 1 Particle systems####

- single particle with gaussian distribution and nonzero mean velocity, colliding with a potential barrier

The future track of the many worlds position state $Xp(t)=[x_1(t)...x_{N*J*D}(t)]$ is determined in general in MIW by system of $N*J*D$ coupled non-linear second order partial differential equations, where $N$=number of worlds, $J$=number of particles, $D$=number of dimensions.
$$
m_k*\ddot{x}_{kn}(t) = f_k(x_n(t)) + r_{kN}(x_n(t);Xp(t))
$$
where $k$ indexes the particle and $n$ the world.

Such a system of $N*J*D$ second order non-linear PDEs can always be written as a system of
of $2*N*J*D$ first order linear PDEs:

$$
\dot{x}_{kn}(t) = y_{kn}(t) \\
\dot{y}_{kn}(t) = (1/m_k)*(f_k(x_n(t)) + r_{kN}(x_n(t))
$$

For our 1 D case, there will be $2N$ equations.
︡344d221c-3046-4dc4-8f90-c6b410e478b5︡{"md":"####Implementation of Wiseman Many-Interacting-Worlds simulation for 1D, 1 Particle systems####\n\n- single particle with gaussian distribution and nonzero mean velocity, colliding with a potential barrier\n\nThe future track of the many worlds position state $Xp(t)=[x_1(t)...x_{N*J*D}(t)]$ is determined in general in MIW by system of $N*J*D$ coupled non-linear second order partial differential equations, where $N$=number of worlds, $J$=number of particles, $D$=number of dimensions.\n$$\nm_k*\\ddot{x}_{kn}(t) = f_k(x_n(t)) + r_{kN}(x_n(t);Xp(t))\n$$\nwhere $k$ indexes the particle and $n$ the world.\n\nSuch a system of $N*J*D$ second order non-linear PDEs can always be written as a system of\nof $2*N*J*D$ first order linear PDEs:\n\n$$\n\\dot{x}_{kn}(t) = y_{kn}(t) \\\\\n\\dot{y}_{kn}(t) = (1/m_k)*(f_k(x_n(t)) + r_{kN}(x_n(t))\n$$\n\nFor our 1 D case, there will be $2N$ equations."}︡
︠0d68b074-a29d-4157-a677-5a79dfbac4e5i︠
%md Setup Sage environment
︡fcb11342-5e06-4b59-a35b-c006a5223d9f︡{"md":"Setup Sage environment"}︡
︠d7e818e1-15b9-4402-8dc8-ad3c54558295︠
%sage
# Better version of FriCAS/Axiom mode for SageMathCloud
os.environ['PATH'] = '%s/bin:%s'%(os.environ['HOME'],os.environ['PATH'])
from fricas import fricas
execfile('fricas_md.py')
%default_mode fricas_md
︡7944cbf0-abb9-488d-9f35-458406dfd916︡
︠69823431-9798-41a5-abfe-e430e38128db︠
)version
)clear completely
)set output tex on
)set output algebra off
)set message type off
︡7ae452f1-a2b7-49ae-bb06-8da03d2f0e8f︡{"md":"\n\nValue = \"FriCAS 2014-12-18 compiled at Tue May  5 18:13:01 UTC 2015\"\n\n   All user variables and function definitions have been cleared.\n\n   All )browse facility databases have been cleared.\n\n   Internally cached functions and constructors have been cleared.\n\n   )clear completely is finished.\n\n"}︡
︠07505980-5031-4e32-ae38-724b0fb61767i︠
%md Classical Force centered at $x=c$ that repells the oncoming particles

︡0c4a6c65-7436-4a43-83ca-5a0aaeb40f11︡{"md":"Classical Force centered at $x=c$ that repells the oncoming particles"}︡
︠4fea43f4-56ab-4887-872a-afed988c397c︠
--F(x) == b*(x-c)/(a^3*%pi)*exp(-(x-c)^2/a^2);
F(x) == 9*sech(5*(x-c))^2*tanh(5*(x-c))
F(x)
︡cad1e9b5-139d-4302-a5bf-f2cf148a2c92︡{"md":"   Compiling function F with type Variable(x) -> Expression(Integer) \n\n\n\n$$\n\n9 \\  {{{\\mathrm{sech}\n\n\\left(\n\n{{{5 \\  x} -{5 \\  c}}} \n\n\\right)}}\n\n^{2}} \\  {\\mathrm{tanh}\n\n\\left(\n\n{{{5 \\  x} -{5 \\  c}}} \n\n\\right)}\n\n\n$$\n\n\n\n"}︡
︠bc7d1168-41a1-4d60-9db6-70fb89119f1a︠
complexNormalize htrigs F(x)
︡2e10e659-cad2-451f-bc64-646748448f6e︡{"md":"\n\n$$\n\n{{{36} \\  {{{{e} ^{{{5 \\  x} -{5 \\  c}}}}} ^{4}}} -{{36} \\  {{{{e} ^{{{5 \\  x} -{5 \\  c}}}}} ^{2}}}} \\over {{{{{e} ^{{{5 \\  x} -{5 \\  c}}}}} ^{6}}+{3 \\  {{{{e} ^{{{5 \\  x} -{5 \\  c}}}}} ^{4}}}+{3 \\  {{{{e} ^{{{5 \\  x} \n\n-{5 \\  c}}}}} ^{2}}}+1} \n\n\n$$\n\n\n\n"}︡
︠8b7f4b4b-bdf1-45fa-b717-05cdbabb6deb︠
%sage
plot(fricas("eval(F(x),[a=0.25,c=5,b=0.7])").sage(),(x,0,10),color="red")
︡3f49329f-5508-4dc6-96fe-ecbb1da7b655︡{"once":false,"file":{"show":true,"uuid":"2058f3dd-2e26-4f75-bcec-7834ab72783e","filename":"/projects/b04b5777-e269-4c8f-a4b8-b21dbe1c93c6/.sage/temp/compute4-us/4454/tmp_QSmSUX.svg"}}︡{"html":"<div align='center'></div>"}︡
︠2ab9133f-a6d6-4fbf-bb37-1826ce5c9959i︠
%md Potential
︡c5488ddb-f343-46e4-823d-56110bae53cb︡{"md":"Potential"}︡
︠8c7a0c13-afd9-40dc-9155-20edfdf502dc︠
%sage
plot(fricas("eval(-integrate(F(x),x),[a=0.25,c=5,b=0.7])").sage(),(x,0,10),color="red")
︡190f7ca6-5e9d-4c73-964a-7bbe3890e6c1︡{"once":false,"file":{"show":true,"uuid":"24d337de-f224-4ec9-a65d-8ad0d6c943c8","filename":"/projects/b04b5777-e269-4c8f-a4b8-b21dbe1c93c6/.sage/temp/compute4-us/4454/tmp_pl5jWw.svg"}}︡{"html":"<div align='center'></div>"}︡
︠0e1072ec-acff-4acf-bf11-7aed2b7bf711i︠
%md Position of particle in the $i^{th}$ world: $x(i)$
︡a3af5376-688a-4af9-993c-b64b432cdef6︡{"md":"Position of particle in the $i^{th}$ world: $x(i)$"}︡
︠69ad7cf6-ec9e-4678-8021-c3e38ba9d081︠
x:=operator('x);
︡54e72e42-b3f4-46de-9bad-797b5fa53a1e︡{"md":"\n\n"}︡
︠75f8d489-12d4-47ba-bb90-f6ed71207f2ei︠
%md
Many Worlds Interaction

Equations 24,25 of HEW paper

︡9356e3c7-9552-4973-aad9-7d85fcf9fb15︡{"md":"Many Worlds Interaction\n\nEquations 24,25 of HEW paper"}︡
︠54a733ff-3a72-4bdc-a190-801d8f1fd70e︠
R(x,i) == (hbar^2/(4*m))*(sigma(x,i+1)-sigma(x,i))
sigma(x,i) == sif(x,i)^2*(sif(x,i+1)-2*sif(x,i)+sif(x,i-1))
sif(x,i) == 1/(x(i)-x(i-1))
︡fc8a4b97-c80d-4b4e-8679-25cc889d888d︡{"md":"\n\n"}︡
︠b0202190-7d66-4c03-8cb2-eb5914415d2fi︠
%md Equations of Motion
︡069d2135-e398-459b-836c-111a8c017f9e︡{"md":"Equations of Motion"}︡
︠5064c8e8-812e-4dd7-90ea-ac91101aced7︠
xdd(i)==(F(x(i))+R(x,i))/m
︡73924835-dfca-42e5-b719-bd3547a4cf3c︡{"md":"\n\n"}︡
︠2c835ce1-0f3f-4861-863a-aa1c7c4fbbcbi︠
%md The non-constant elements of the Jacobian matrix are formed from derivates with respect to x
︡94ff747b-f678-4109-8f44-d72970936682︡{"md":"The non-constant elements of the Jacobian matrix are formed from derivates with respect to x"}︡
︠f3679e35-4657-4d9a-b014-21c7a71b9514︠
jac1(i,j)==realElementary eval(D(eval(xdd(i),x(i+j)=%x),%x),%x=x(i+j))
︡bd18befa-e116-4712-889f-331598049a82︡{"md":"\n\n"}︡
︠b514d069-55e4-4f1d-8567-d763b687247ai︠
%md Sage routine to convert FriCAS expression to Octave function
︡8c4d4885-64c1-44c0-b15a-0683e698cbef︡{"md":"Sage routine to convert FriCAS expression to Octave function"}︡
︠c680635f-5df9-416d-9a31-4c1cb1fd4276︠
%sage
# fold lines for octave
def split_lines(fr):
  i=0; cpl=80; f=""
  while i<len(fr):
    if i+cpl>=len(fr):
      f+= "    "+fr[i:i+cpl]+";\n"
      i=i+cpl
    else:
      line=fr[i:i+cpl]
      p=line.rfind('*', 0, cpl)+1
      if p==0:
        p=line.rindex('+', 0, cpl)+1
      f+= "    "+fr[i:i+p]+"...\n"
      i=i+p
  return f[4:len(f)-1]
︡ea9d5e15-badf-4a4a-8cee-772bd0220e3f︡
︠e121572a-8255-4ff5-bf43-3b5f096ecd16︠
%sage
# name of function defined by fricas expression ex
def fricas2octave(name,ex):
  fr=fricas(ex).unparsed_input_form()
  # cleanup fricas expresssion
  fr = fr.replace("\n","")
  fr = fr.replace("\r","")
  fr = fr.replace(" -","-")
  fr = fr.replace("+-","-")
  # boundry conditions
  fr = fr.replace("x(i-2)","xl2")
  fr = fr.replace("x(i-1)","xl1")
  fr = fr.replace("x(i+1)","xr1")
  fr = fr.replace("x(i+2)","xr2")
  f = """\
function result=%s(x,i)
  global l2 l1 p1 p2;
  global N m hbar a b c;
  if (i-2<1)
    xl2=l2;
  else
    xl2=x(i-2);
  endif;
  if (i-1<1)
    xl1=l1;
  else
    xl1=x(i-1);
  endif;
  if (i+2>N)
    xr2=p2;
  else
    xr2=x(i+2);
  endif;
  if (i+1>N)
    xr1=p1;
  else
    xr1=x(i+1);
  endif;
  result=%s
endfunction
"""%(name,split_lines(fr))
  ff = open('%s.m'%name, 'w')
  ff.write(f)
  ff.close()
  return f
︡77dd3da7-0228-4f30-8efb-cbbaf5d725bc︡
︠01ba0174-660b-47ee-8632-5e132bd6e038︠
%sage
# Use a better version of the octave interface
from octave import octave
%default_mode octave
︡dc6f0f77-0c1b-43cf-a3b3-cfc61a51014c︡
︠4696dec3-8020-449f-9981-776a61fcdf05i︠
%md Generate initial distribution of particle states, including position,x (X0), and velocity, xdot (Y0)
︡a64bf847-ee05-4ed4-93de-12a2bbbd691f︡{"md":"Generate initial distribution of particle states, including position,x (X0), and velocity, xdot (Y0)"}︡
︠e80ebed3-2908-4091-88d6-c9539e7275d5︠
clear all;
version
︡35b9b23c-ba55-4f24-8671-7ec7c0e53f78︡{"stdout":"\nans = 3.8.2"}︡
︠9b00ab38-0738-464d-bb6f-bd5c548b2121i︠

%md For a simple test, distribute 101 values equally over a window and set all velocities to zero
︡771e9e51-4f8d-452c-9f75-5477b32b5629︡{"md":"For a simple test, distribute 101 values equally over a window and set all velocities to zero"}︡
︠4492b3a8-378d-4361-b71d-be98bd81d851︠
#xvalues=[-1:.05:1]'; #Prob2
#xvalues=[-1:.025:1]'; #Prob3
#xvalues=[-0.5:.025:0.5]'; #Prob4
︡2b05d651-feba-4159-9cc9-f936796d0ab3︡{"stdout":"\n\n"}︡
︠16ee0771-03f1-4e0b-b9cb-df6bbeb7708ci︠
%md Use inverse error function to generate a Gaussian distribution of trajectories
︡8992d300-be41-49b8-9b12-f321d7381e12︡{"md":"Use inverse error function to generate a Gaussian distribution of trajectories"}︡
︠f7b01f7b-7b4a-4e50-b660-25cc8e91ca78︠
#xuniform=[-0.95:0.1:0.95]'; %For the simple test
#xuniform=[-0.95:0.022|:0.95]';
xuniform=[-0.99:0.15:0.99]';
#xvalues=erfcinv(xuniform);
xvalues=erfinv(xuniform);
global N; %Number of worlds
N = size(xvalues,1)
X0 = xvalues;
#Y0 = zeros(N,1); %zero initial velocities
#Y0 = normrnd(1, 0.2, N, 1);
Y0 = ones(N,1); %non-zero initial velocities
︡3637806d-0330-4215-84bc-256e631891eb︡{"stdout":"N = 14"}︡
︠aad31839-df37-4681-9d1e-8dfbe8f5714ai︠
%md Plot the input trajectory density
︡b9a2f9a4-1b9c-4bca-ae27-4020403c5292︡{"md":"Plot the input trajectory density"}︡
︠254143b7-d2fe-43d6-acb6-60aa89eb8172︠
Pin=(N*(xvalues(2:N,1)-xvalues(1:(N-1),1))).^(-1);
︡08871554-fff4-4037-904e-567cb4b52f3e︡
︠4bf9fcb9-8b0b-4a2d-968d-80bca98ec2d5︠
%sage list_plot(matrix(RR,octave("[xvalues(2:N),Pin]")),plotjoined=true)
︡c8942d15-62e3-4e84-8ce9-91a136791527︡{"once":false,"file":{"show":true,"uuid":"45687a56-3053-4283-b111-c761c294f5b3","filename":"/projects/b04b5777-e269-4c8f-a4b8-b21dbe1c93c6/.sage/temp/compute4-us/4454/tmp_or2JUL.svg"}}︡{"html":"<div align='center'></div>"}︡
︠8fbd4e60-0c9c-4100-a266-9bd1d529aa0ei︠
%md Constants
︡5ba96122-c9da-40b4-a36f-8261426d5914︡{"md":"Constants"}︡
︠65782667-265b-49f0-94e7-8c54d69cf1d6︠
global m hbar;
m = 1; %mass of particle
hbar = 0.1; %Planck constant %.02 works but nonguassian after 500 iterations
global a b c;
a = 0.25;
b = 0.7;
c = 5;
︡56cca7b7-6103-4f2a-ae5e-528c1f46ee67︡
︠76d029b1-b94b-481d-99cd-434e92df5040i︠
%md Boundry conditions
︡446b9cb7-c2e3-4b79-beef-8616b5629b49︡{"md":"Boundry conditions"}︡
︠16d7ad46-61fe-4e8c-9e25-0acef869b923︠
global l2 l1 p1 p2;
l2 = -100000;
l1 =  -10000;
p1 =   10000;
p2 =  100000;
︡07322c10-f5ed-47b4-838c-57e0fadb3191︡{"stdout":"\n\n\n\n"}︡
︠925166e2-9b8d-4c57-af01-fccb923d9986︠
%sage
octave.eval("global F = @(x) "+fricas("F('x)").unparsed_input_form().replace("pi()","pi"))
︡75e26073-30c3-429a-b1c4-a9bb4bdace44︡{"stdout":"''\n"}︡
︠facdb9b4-7868-4c9e-91d2-56f0d792eacfi︠
%md Plot the force
︡57ef58ce-1185-44d1-8c59-bf8d7541ec6a︡{"md":"Plot the force"}︡
︠fa6e07b3-ea60-4844-8bed-8e205d86c243︠
Xrange = 0:0.05:10;
︡ff05ccdc-2ed5-496f-835e-da9cd78a097f︡
︠e025051e-e8a7-4e68-97b2-005aa70d7ddd︠
%sage list_plot(matrix(RR,octave("[Xrange',arrayfun(F,Xrange')]")),plotjoined=true)
︡8d1989fd-0cbb-49e8-b9fb-6e00b4171ade︡{"once":false,"file":{"show":true,"uuid":"557ea463-d43c-4c16-aaff-14681343610b","filename":"/projects/b04b5777-e269-4c8f-a4b8-b21dbe1c93c6/.sage/temp/compute4-us/4454/tmp_An_qeK.svg"}}︡{"html":"<div align='center'></div>"}︡
︠8fa89475-7c1c-442d-8f65-2a58eab1c370︠
%sage print fricas2octave('R2','R(x,i)')
︡33e49471-ea64-4e06-be7e-3bd16c7a9bfe︡{"stdout":"function result=R2(x,i)\n  global l2 l1 p1 p2;\n  global N m hbar a b c;\n  if (i-2<1)\n    xl2=l2;\n  else\n    xl2=x(i-2);\n  endif;\n  if (i-1<1)\n    xl1=l1;\n  else\n    xl1=x(i-1);\n  endif;\n  if (i+2>N)\n    xr2=p2;\n  else\n    xr2=x(i+2);\n  endif;\n  if (i+1>N)\n    xr1=p1;\n  else\n    xr1=x(i+1);\n  endif;\n  result=(((-1*hbar^2*x(i)+(3*hbar^2*xl1-2*hbar^2*xl2))*xr1^3+(3*hbar^2*x(i)^2+(-10*...\n    hbar^2*xl1+7*hbar^2*xl2)*x(i)+(hbar^2*xl1^2-1*hbar^2*xl2*xl1))*xr1^2+(-3*hbar^2*...\n    x(i)^3+(12*hbar^2*xl1-9*hbar^2*xl2)*x(i)^2+(-4*hbar^2*xl1^2+4*hbar^2*xl2*xl1)*...\n    x(i)+(hbar^2*xl1^3-1*hbar^2*xl2*xl1^2))*xr1+(hbar^2*x(i)^4+(-7*hbar^2*xl1+6*...\n    hbar^2*xl2)*x(i)^3+(9*hbar^2*xl1^2-9*hbar^2*xl2*xl1)*x(i)^2+(-7*hbar^2*xl1^3+7*...\n    hbar^2*xl2*xl1^2)*x(i)+(2*hbar^2*xl1^4-2*hbar^2*xl2*xl1^3)))*xr2+((hbar^2*...\n    x(i)+(-3*hbar^2*xl1+2*hbar^2*xl2))*xr1^4+(-3*hbar^2*x(i)^2+(10*hbar^2*xl1-7*...\n    hbar^2*xl2)*x(i)+(-1*hbar^2*xl1^2+hbar^2*xl2*xl1))*xr1^3+(3*hbar^2*x(i)^3+(-12*...\n    hbar^2*xl1+9*hbar^2*xl2)*x(i)^2+(4*hbar^2*xl1^2-4*hbar^2*xl2*xl1)*x(i)+(-1*...\n    hbar^2*xl1^3+hbar^2*xl2*xl1^2))*xr1^2+(-1*hbar^2*x(i)^4+(8*hbar^2*xl1-7*hbar^2*...\n    xl2)*x(i)^3+(-12*hbar^2*xl1^2+12*hbar^2*xl2*xl1)*x(i)^2+(10*hbar^2*xl1^3-10*...\n    hbar^2*xl2*xl1^2)*x(i)+(-3*hbar^2*xl1^4+3*hbar^2*xl2*xl1^3))*xr1+((-1*hbar^2*...\n    xl1+hbar^2*xl2)*x(i)^4+(3*hbar^2*xl1^2-3*hbar^2*xl2*xl1)*x(i)^3+(-3*hbar^2*...\n    xl1^3+3*hbar^2*xl2*xl1^2)*x(i)^2+(hbar^2*xl1^4-1*hbar^2*xl2*xl1^3)*...\n    x(i))))/((((4*m*xl1-4*m*xl2)*x(i)^3+(-12*m*xl1^2+12*m*xl2*xl1)*x(i)^2+(12*m*...\n    xl1^3-12*m*xl2*xl1^2)*x(i)+(-4*m*xl1^4+4*m*xl2*xl1^3))*xr1^3+((-12*m*xl1+12*m*...\n    xl2)*x(i)^4+(36*m*xl1^2-36*m*xl2*xl1)*x(i)^3+(-36*m*xl1^3+36*m*xl2*xl1^2)*...\n    x(i)^2+(12*m*xl1^4-12*m*xl2*xl1^3)*x(i))*xr1^2+((12*m*xl1-12*m*xl2)*x(i)^5+(-36*...\n    m*xl1^2+36*m*xl2*xl1)*x(i)^4+(36*m*xl1^3-36*m*xl2*xl1^2)*x(i)^3+(-12*m*xl1^4+12*...\n    m*xl2*xl1^3)*x(i)^2)*xr1+((-4*m*xl1+4*m*xl2)*x(i)^6+(12*m*xl1^2-12*m*xl2*xl1)*...\n    x(i)^5+(-12*m*xl1^3+12*m*xl2*xl1^2)*x(i)^4+(4*m*xl1^4-4*m*xl2*xl1^3)*x(i)^3))*...\n    xr2+(((-4*m*xl1+4*m*xl2)*x(i)^3+(12*m*xl1^2-12*m*xl2*xl1)*x(i)^2+(-12*m*...\n    xl1^3+12*m*xl2*xl1^2)*x(i)+(4*m*xl1^4-4*m*xl2*xl1^3))*xr1^4+((12*m*xl1-12*m*...\n    xl2)*x(i)^4+(-36*m*xl1^2+36*m*xl2*xl1)*x(i)^3+(36*m*xl1^3-36*m*xl2*xl1^2)*...\n    x(i)^2+(-12*m*xl1^4+12*m*xl2*xl1^3)*x(i))*xr1^3+((-12*m*xl1+12*m*xl2)*...\n    x(i)^5+(36*m*xl1^2-36*m*xl2*xl1)*x(i)^4+(-36*m*xl1^3+36*m*xl2*xl1^2)*x(i)^3+(12*...\n    m*xl1^4-12*m*xl2*xl1^3)*x(i)^2)*xr1^2+((4*m*xl1-4*m*xl2)*x(i)^6+(-12*m*xl1^2+12*...\n    m*xl2*xl1)*x(i)^5+(12*m*xl1^3-12*m*xl2*xl1^2)*x(i)^4+(-4*m*xl1^4+4*m*xl2*xl1^3)*...\n    x(i)^3)*xr1));\nendfunction\n"}︡{"stdout":"\n"}︡
︠5177c81a-5099-4f7a-93c3-a42f2291a8ea︠
R2(X0,3)
︡201ab168-1b3b-4c8a-9ec5-136f7a1d83fc︡{"stdout":"ans = 0.00280219"}︡
︠b6b04a5d-63ab-4f1b-bc23-dba683bd45fa︠
function r = R(x,i)
  global m hbar;
  r = (hbar^2/(4*m))*(sigma(x,i+1)-sigma(x,i));
endfunction;

function s=sigma(x,i)
 s = sif(x,i)^2*(sif(x,i+1)-2*sif(x,i)+sif(x,i-1));
endfunction;

function den = sif(x,i)
  global N
  if (i>N)||(i<2)
    den=0;
  else
    den=1/(x(i)-x(i-1));
  endif
endfunction;
︡081a7a3d-167b-40cf-9c01-5830b04df8c9︡
︠88dd5e6d-06e2-4807-8408-eadf583dfd12︠
R2(X0,3)
︡83590e1e-d6e6-4b8f-a28a-4ea3b483cd34︡{"stdout":"ans = 0.00280219"}︡
︠1102cd21-f779-4c1f-810b-13fbb0d1f645︠
%sage
X=map(eval,str(octave('X0')).splitlines()[2:-1]);X
︡e2b8cf33-be4e-49a8-8178-ee951a71ede9︡{"stdout":"[-1.82139, -0.993536, -0.71787, -0.522444, -0.360676, -0.216008, -0.0799303, 0.0532238, 0.18831, 0.330713, 0.488122, 0.674697, 0.926719, 1.45222]\n"}︡
︠56593f91-d24d-4bda-9a61-7f9b5cb8b644︠
%sage
print fricas.eval("X:=%s;"%(fricas(X).name()))
︡15136594-f7f8-4330-894b-ab82cf09f5dc︡{"stdout":"\r\n\n"}︡
︠41e8b492-6b4e-4f91-8ab8-ca6367b82c49︠
%fricas_md
eval(R(X,3),[hbar=0.1,m=1])
︡d3b72154-5264-4b4b-99c4-79b02f35740b︡{"md":"   Compiling function sif with type (List(Float),PositiveInteger) -> Float \n\n   Compiling function sif with type (List(Float),Integer) -> Float \n\n   Compiling function sigma with type (List(Float),PositiveInteger) -> Float \n\n   Compiling function R with type (List(Float),PositiveInteger) -> Fraction(Polynomial(Float)) \n\n\n\n$$\n\n0.0027954071\\_1864352625\\_97 \n\n\n$$\n\n\n\n"}︡
︠672296a6-94db-417b-b690-7278c3e5d9cei︠
%md Equations of motion in numeric form
︡895241b8-c48e-42f0-a142-66dad6c44037︡{"md":"Equations of motion in numeric form"}︡
︠16eed5a1-e82f-4044-af07-452743c2d84a︠
function xdot = deq(x,t)
    global F N;
    for i=1:N
      xdot(i) = x(N+i);
      xdot(N+i) = F(x(i))+R(x,i);
    endfor
endfunction
︡760ab84b-7a60-4a53-9434-064364b24dbf︡
︠9bd3aee3-e26c-4a18-b8cd-45405a914777i︠
%md Functions to compute the Jacobian matrix
︡7d406ba7-b8a2-4b06-9b97-7c59961e45d9︡{"md":"Functions to compute the Jacobian matrix"}︡
︠9222cd05-343e-44ba-8f18-0802aa1dceaf︠
%sage print fricas2octave('Jm2','jac1(i,-2)')
︡930401f2-cd5a-4e82-b104-85d1a8fcf297︡{"stdout":"function result=Jm2(x,i)\n  global l2 l1 p1 p2;\n  global N m hbar a b c;\n  if (i-2<1)\n    xl2=l2;\n  else\n    xl2=x(i-2);\n  endif;\n  if (i-1<1)\n    xl1=l1;\n  else\n    xl1=x(i-1);\n  endif;\n  if (i+2>N)\n    xr2=p2;\n  else\n    xr2=x(i+2);\n  endif;\n  if (i+1>N)\n    xr1=p1;\n  else\n    xr1=x(i+1);\n  endif;\n  result=(-1*hbar^2)/((4*m^2*xl1^2-8*m^2*xl2*xl1+4*m^2*xl2^2)*x(i)^2+(-8*m^2*xl1^3+16*...\n    m^2*xl2*xl1^2-8*m^2*xl2^2*xl1)*x(i)+(4*m^2*xl1^4-8*m^2*xl2*xl1^3+4*m^2*xl2^2*...\n    xl1^2));\nendfunction\n\n"}︡
︠9d14bfc9-5a82-4684-888e-54640db7ed7b︠
%sage print fricas2octave('Jm1','jac1(i,-1)')
︡9bdff5e0-41ed-40ce-9265-528b1baaf900︡{"stdout":"function result=Jm1(x,i)\n  global l2 l1 p1 p2;\n  global N m hbar a b c;\n  if (i-2<1)\n    xl2=l2;\n  else\n    xl2=x(i-2);\n  endif;\n  if (i-1<1)\n    xl1=l1;\n  else\n    xl1=x(i-1);\n  endif;\n  if (i+2>N)\n    xr2=p2;\n  else\n    xr2=x(i+2);\n  endif;\n  if (i+1>N)\n    xr1=p1;\n  else\n    xr1=x(i+1);\n  endif;\n  result=((hbar^2*x(i)^2+(-4*hbar^2*xl1+2*hbar^2*xl2)*x(i)+(9*hbar^2*xl1^2-14*hbar^2*xl2*...\n    xl1+6*hbar^2*xl2^2))*xr1^2+(-2*hbar^2*x(i)^3+(8*hbar^2*xl1-4*hbar^2*xl2)*...\n    x(i)^2+(-20*hbar^2*xl1^2+32*hbar^2*xl2*xl1-14*hbar^2*xl2^2)*x(i)+(2*hbar^2*...\n    xl1^3-4*hbar^2*xl2*xl1^2+2*hbar^2*xl2^2*xl1))*xr1+(hbar^2*x(i)^4+(-4*hbar^2*...\n    xl1+2*hbar^2*xl2)*x(i)^3+(12*hbar^2*xl1^2-20*hbar^2*xl2*xl1+9*hbar^2*xl2^2)*...\n    x(i)^2+(-4*hbar^2*xl1^3+8*hbar^2*xl2*xl1^2-4*hbar^2*xl2^2*xl1)*x(i)+(hbar^2*...\n    xl1^4-2*hbar^2*xl2*xl1^3+hbar^2*xl2^2*xl1^2)))/(((4*m^2*xl1^2-8*m^2*xl2*xl1+4*...\n    m^2*xl2^2)*x(i)^4+(-16*m^2*xl1^3+32*m^2*xl2*xl1^2-16*m^2*xl2^2*xl1)*x(i)^3+(24*...\n    m^2*xl1^4-48*m^2*xl2*xl1^3+24*m^2*xl2^2*xl1^2)*x(i)^2+(-16*m^2*xl1^5+32*m^2*xl2*...\n    xl1^4-16*m^2*xl2^2*xl1^3)*x(i)+(4*m^2*xl1^6-8*m^2*xl2*xl1^5+4*m^2*xl2^2*xl1^4))*...\n    xr1^2+((-8*m^2*xl1^2+16*m^2*xl2*xl1-8*m^2*xl2^2)*x(i)^5+(32*m^2*xl1^3-64*m^2*...\n    xl2*xl1^2+32*m^2*xl2^2*xl1)*x(i)^4+(-48*m^2*xl1^4+96*m^2*xl2*xl1^3-48*m^2*xl2^2*...\n    xl1^2)*x(i)^3+(32*m^2*xl1^5-64*m^2*xl2*xl1^4+32*m^2*xl2^2*xl1^3)*x(i)^2+(-8*m^2*...\n    xl1^6+16*m^2*xl2*xl1^5-8*m^2*xl2^2*xl1^4)*x(i))*xr1+((4*m^2*xl1^2-8*m^2*xl2*...\n    xl1+4*m^2*xl2^2)*x(i)^6+(-16*m^2*xl1^3+32*m^2*xl2*xl1^2-16*m^2*xl2^2*xl1)*...\n    x(i)^5+(24*m^2*xl1^4-48*m^2*xl2*xl1^3+24*m^2*xl2^2*xl1^2)*x(i)^4+(-16*m^2*...\n    xl1^5+32*m^2*xl2*xl1^4-16*m^2*xl2^2*xl1^3)*x(i)^3+(4*m^2*xl1^6-8*m^2*xl2*...\n    xl1^5+4*m^2*xl2^2*xl1^4)*x(i)^2));\nendfunction\n"}︡{"stdout":"\n"}︡
︠eb474f4e-2c37-49cb-baa7-c8b3e4974132︠
%sage print fricas2octave('J0','jac1(i,0)')
︡74fef2d0-da83-4239-94df-e25827d9e0a2︡{"stdout":"function result=J0(x,i)\n  global l2 l1 p1 p2;\n  global N m hbar a b c;\n  if (i-2<1)\n    xl2=l2;\n  else\n    xl2=x(i-2);\n  endif;\n  if (i-1<1)\n    xl1=l1;\n  else\n    xl1=x(i-1);\n  endif;\n  if (i+2>N)\n    xr2=p2;\n  else\n    xr2=x(i+2);\n  endif;\n  if (i+1>N)\n    xr1=p1;\n  else\n    xr1=x(i+1);\n  endif;\n  result=((((hbar^2*x(i)+(-4*hbar^2*xl1+3*hbar^2*xl2))*xr1^4+(-4*hbar^2*x(i)^2+(17*...\n    hbar^2*xl1-13*hbar^2*xl2)*x(i)+(-1*hbar^2*xl1^2+hbar^2*xl2*xl1))*xr1^3+(6*...\n    hbar^2*x(i)^3+(-28*hbar^2*xl1+22*hbar^2*xl2)*x(i)^2+(5*hbar^2*xl1^2-5*hbar^2*...\n    xl2*xl1)*x(i)+(-1*hbar^2*xl1^3+hbar^2*xl2*xl1^2))*xr1^2+(-4*hbar^2*x(i)^4+(22*...\n    hbar^2*xl1-18*hbar^2*xl2)*x(i)^3+(-10*hbar^2*xl1^2+10*hbar^2*xl2*xl1)*x(i)^2+(5*...\n    hbar^2*xl1^3-5*hbar^2*xl2*xl1^2)*x(i)+(-1*hbar^2*xl1^4+hbar^2*xl2*xl1^3))*...\n    xr1+(hbar^2*x(i)^5+(-10*hbar^2*xl1+9*hbar^2*xl2)*x(i)^4+(18*hbar^2*xl1^2-18*...\n    hbar^2*xl2*xl1)*x(i)^3+(-22*hbar^2*xl1^3+22*hbar^2*xl2*xl1^2)*x(i)^2+(13*hbar^2*...\n    xl1^4-13*hbar^2*xl2*xl1^3)*x(i)+(-3*hbar^2*xl1^5+3*hbar^2*xl2*xl1^4)))*xr2+((-1*...\n    hbar^2*x(i)+(4*hbar^2*xl1-3*hbar^2*xl2))*xr1^5+(4*hbar^2*x(i)^2+(-17*hbar^2*...\n    xl1+13*hbar^2*xl2)*x(i)+(hbar^2*xl1^2-1*hbar^2*xl2*xl1))*xr1^4+(-6*hbar^2*...\n    x(i)^3+(28*hbar^2*xl1-22*hbar^2*xl2)*x(i)^2+(-5*hbar^2*xl1^2+5*hbar^2*xl2*xl1)*...\n    x(i)+(hbar^2*xl1^3-1*hbar^2*xl2*xl1^2))*xr1^3+(4*hbar^2*x(i)^4+(-22*hbar^2*...\n    xl1+18*hbar^2*xl2)*x(i)^3+(10*hbar^2*xl1^2-10*hbar^2*xl2*xl1)*x(i)^2+(-5*hbar^2*...\n    xl1^3+5*hbar^2*xl2*xl1^2)*x(i)+(hbar^2*xl1^4-1*hbar^2*xl2*xl1^3))*xr1^2+(-1*...\n    hbar^2*x(i)^5+(11*hbar^2*xl1-10*hbar^2*xl2)*x(i)^4+(-22*hbar^2*xl1^2+22*hbar^2*...\n    xl2*xl1)*x(i)^3+(28*hbar^2*xl1^3-28*hbar^2*xl2*xl1^2)*x(i)^2+(-17*hbar^2*...\n    xl1^4+17*hbar^2*xl2*xl1^3)*x(i)+(4*hbar^2*xl1^5-4*hbar^2*xl2*xl1^4))*xr1+((-1*...\n    hbar^2*xl1+hbar^2*xl2)*x(i)^5+(4*hbar^2*xl1^2-4*hbar^2*xl2*xl1)*x(i)^4+(-6*...\n    hbar^2*xl1^3+6*hbar^2*xl2*xl1^2)*x(i)^3+(4*hbar^2*xl1^4-4*hbar^2*xl2*xl1^3)*...\n    x(i)^2+(-1*hbar^2*xl1^5+hbar^2*xl2*xl1^4)*x(i))))*exp(5*x(i)-5*c)^8+((((-720*m*...\n    xl1+720*m*xl2)*x(i)^4+(2880*m*xl1^2-2880*m*xl2*xl1)*x(i)^3+(-4320*m*xl1^3+4320*...\n    m*xl2*xl1^2)*x(i)^2+(2880*m*xl1^4-2880*m*xl2*xl1^3+4*hbar^2)*x(i)+(-720*m*...\n    xl1^5+720*m*xl2*xl1^4-16*hbar^2*xl1+12*hbar^2*xl2))*xr1^4+((2880*m*xl1-2880*m*...\n    xl2)*x(i)^5+(-11520*m*xl1^2+11520*m*xl2*xl1)*x(i)^4+(17280*m*xl1^3-17280*m*xl2*...\n    xl1^2)*x(i)^3+(-11520*m*xl1^4+11520*m*xl2*xl1^3-16*hbar^2)*x(i)^2+(2880*m*...\n    xl1^5-2880*m*xl2*xl1^4+68*hbar^2*xl1-52*hbar^2*xl2)*x(i)+(-4*hbar^2*xl1^2+4*...\n    hbar^2*xl2*xl1))*xr1^3+((-4320*m*xl1+4320*m*xl2)*x(i)^6+(17280*m*xl1^2-17280*m*...\n    xl2*xl1)*x(i)^5+(-25920*m*xl1^3+25920*m*xl2*xl1^2)*x(i)^4+(17280*m*xl1^4-17280*...\n    m*xl2*xl1^3+24*hbar^2)*x(i)^3+(-4320*m*xl1^5+4320*m*xl2*xl1^4-112*hbar^2*xl1+88*...\n    hbar^2*xl2)*x(i)^2+(20*hbar^2*xl1^2-20*hbar^2*xl2*xl1)*x(i)+(-4*hbar^2*xl1^3+4*...\n    hbar^2*xl2*xl1^2))*xr1^2+((2880*m*xl1-2880*m*xl2)*x(i)^7+(-11520*m*xl1^2+11520*...\n    m*xl2*xl1)*x(i)^6+(17280*m*xl1^3-17280*m*xl2*xl1^2)*x(i)^5+(-11520*m*...\n    xl1^4+11520*m*xl2*xl1^3-16*hbar^2)*x(i)^4+(2880*m*xl1^5-2880*m*xl2*xl1^4+88*...\n    hbar^2*xl1-72*hbar^2*xl2)*x(i)^3+(-40*hbar^2*xl1^2+40*hbar^2*xl2*xl1)*...\n    x(i)^2+(20*hbar^2*xl1^3-20*hbar^2*xl2*xl1^2)*x(i)+(-4*hbar^2*xl1^4+4*hbar^2*xl2*...\n    xl1^3))*xr1+((-720*m*xl1+720*m*xl2)*x(i)^8+(2880*m*xl1^2-2880*m*xl2*xl1)*...\n    x(i)^7+(-4320*m*xl1^3+4320*m*xl2*xl1^2)*x(i)^6+(2880*m*xl1^4-2880*m*xl2*xl1^3+4*...\n    hbar^2)*x(i)^5+(-720*m*xl1^5+720*m*xl2*xl1^4-40*hbar^2*xl1+36*hbar^2*xl2)*...\n    x(i)^4+(72*hbar^2*xl1^2-72*hbar^2*xl2*xl1)*x(i)^3+(-88*hbar^2*xl1^3+88*hbar^2*...\n    xl2*xl1^2)*x(i)^2+(52*hbar^2*xl1^4-52*hbar^2*xl2*xl1^3)*x(i)+(-12*hbar^2*...\n    xl1^5+12*hbar^2*xl2*xl1^4)))*xr2+(((720*m*xl1-720*m*xl2)*x(i)^4+(-2880*m*...\n    xl1^2+2880*m*xl2*xl1)*x(i)^3+(4320*m*xl1^3-4320*m*xl2*xl1^2)*x(i)^2+(-2880*m*...\n    xl1^4+2880*m*xl2*xl1^3-4*hbar^2)*x(i)+(720*m*xl1^5-720*m*xl2*xl1^4+16*hbar^2*...\n    xl1-12*hbar^2*xl2))*xr1^5+((-2880*m*xl1+2880*m*xl2)*x(i)^5+(11520*m*xl1^2-11520*...\n    m*xl2*xl1)*x(i)^4+(-17280*m*xl1^3+17280*m*xl2*xl1^2)*x(i)^3+(11520*m*...\n    xl1^4-11520*m*xl2*xl1^3+16*hbar^2)*x(i)^2+(-2880*m*xl1^5+2880*m*xl2*xl1^4-68*...\n    hbar^2*xl1+52*hbar^2*xl2)*x(i)+(4*hbar^2*xl1^2-4*hbar^2*xl2*xl1))*xr1^4+((4320*...\n    m*xl1-4320*m*xl2)*x(i)^6+(-17280*m*xl1^2+17280*m*xl2*xl1)*x(i)^5+(25920*m*...\n    xl1^3-25920*m*xl2*xl1^2)*x(i)^4+(-17280*m*xl1^4+17280*m*xl2*xl1^3-24*hbar^2)*...\n    x(i)^3+(4320*m*xl1^5-4320*m*xl2*xl1^4+112*hbar^2*xl1-88*hbar^2*xl2)*x(i)^2+(-20*...\n    hbar^2*xl1^2+20*hbar^2*xl2*xl1)*x(i)+(4*hbar^2*xl1^3-4*hbar^2*xl2*xl1^2))*...\n    xr1^3+((-2880*m*xl1+2880*m*xl2)*x(i)^7+(11520*m*xl1^2-11520*m*xl2*xl1)*...\n    x(i)^6+(-17280*m*xl1^3+17280*m*xl2*xl1^2)*x(i)^5+(11520*m*xl1^4-11520*m*xl2*...\n    xl1^3+16*hbar^2)*x(i)^4+(-2880*m*xl1^5+2880*m*xl2*xl1^4-88*hbar^2*xl1+72*hbar^2*...\n    xl2)*x(i)^3+(40*hbar^2*xl1^2-40*hbar^2*xl2*xl1)*x(i)^2+(-20*hbar^2*xl1^3+20*...\n    hbar^2*xl2*xl1^2)*x(i)+(4*hbar^2*xl1^4-4*hbar^2*xl2*xl1^3))*xr1^2+((720*m*...\n    xl1-720*m*xl2)*x(i)^8+(-2880*m*xl1^2+2880*m*xl2*xl1)*x(i)^7+(4320*m*xl1^3-4320*...\n    m*xl2*xl1^2)*x(i)^6+(-2880*m*xl1^4+2880*m*xl2*xl1^3-4*hbar^2)*x(i)^5+(720*m*...\n    xl1^5-720*m*xl2*xl1^4+44*hbar^2*xl1-40*hbar^2*xl2)*x(i)^4+(-88*hbar^2*xl1^2+88*...\n    hbar^2*xl2*xl1)*x(i)^3+(112*hbar^2*xl1^3-112*hbar^2*xl2*xl1^2)*x(i)^2+(-68*...\n    hbar^2*xl1^4+68*hbar^2*xl2*xl1^3)*x(i)+(16*hbar^2*xl1^5-16*hbar^2*xl2*xl1^4))*...\n    xr1+((-4*hbar^2*xl1+4*hbar^2*xl2)*x(i)^5+(16*hbar^2*xl1^2-16*hbar^2*xl2*xl1)*...\n    x(i)^4+(-24*hbar^2*xl1^3+24*hbar^2*xl2*xl1^2)*x(i)^3+(16*hbar^2*xl1^4-16*hbar^2*...\n    xl2*xl1^3)*x(i)^2+(-4*hbar^2*xl1^5+4*hbar^2*xl2*xl1^4)*x(i))))*exp(5*x(i)-5*...\n    c)^6+((((2880*m*xl1-2880*m*xl2)*x(i)^4+(-11520*m*xl1^2+11520*m*xl2*xl1)*...\n    x(i)^3+(17280*m*xl1^3-17280*m*xl2*xl1^2)*x(i)^2+(-11520*m*xl1^4+11520*m*xl2*...\n    xl1^3+6*hbar^2)*x(i)+(2880*m*xl1^5-2880*m*xl2*xl1^4-24*hbar^2*xl1+18*hbar^2*...\n    xl2))*xr1^4+((-11520*m*xl1+11520*m*xl2)*x(i)^5+(46080*m*xl1^2-46080*m*xl2*xl1)*...\n    x(i)^4+(-69120*m*xl1^3+69120*m*xl2*xl1^2)*x(i)^3+(46080*m*xl1^4-46080*m*xl2*...\n    xl1^3-24*hbar^2)*x(i)^2+(-11520*m*xl1^5+11520*m*xl2*xl1^4+102*hbar^2*xl1-78*...\n    hbar^2*xl2)*x(i)+(-6*hbar^2*xl1^2+6*hbar^2*xl2*xl1))*xr1^3+((17280*m*xl1-17280*...\n    m*xl2)*x(i)^6+(-69120*m*xl1^2+69120*m*xl2*xl1)*x(i)^5+(103680*m*xl1^3-103680*m*...\n    xl2*xl1^2)*x(i)^4+(-69120*m*xl1^4+69120*m*xl2*xl1^3+36*hbar^2)*x(i)^3+(17280*m*...\n    xl1^5-17280*m*xl2*xl1^4-168*hbar^2*xl1+132*hbar^2*xl2)*x(i)^2+(30*hbar^2*...\n    xl1^2-30*hbar^2*xl2*xl1)*x(i)+(-6*hbar^2*xl1^3+6*hbar^2*xl2*xl1^2))*...\n    xr1^2+((-11520*m*xl1+11520*m*xl2)*x(i)^7+(46080*m*xl1^2-46080*m*xl2*xl1)*...\n    x(i)^6+(-69120*m*xl1^3+69120*m*xl2*xl1^2)*x(i)^5+(46080*m*xl1^4-46080*m*xl2*...\n    xl1^3-24*hbar^2)*x(i)^4+(-11520*m*xl1^5+11520*m*xl2*xl1^4+132*hbar^2*xl1-108*...\n    hbar^2*xl2)*x(i)^3+(-60*hbar^2*xl1^2+60*hbar^2*xl2*xl1)*x(i)^2+(30*hbar^2*...\n    xl1^3-30*hbar^2*xl2*xl1^2)*x(i)+(-6*hbar^2*xl1^4+6*hbar^2*xl2*xl1^3))*...\n    xr1+((2880*m*xl1-2880*m*xl2)*x(i)^8+(-11520*m*xl1^2+11520*m*xl2*xl1)*...\n    x(i)^7+(17280*m*xl1^3-17280*m*xl2*xl1^2)*x(i)^6+(-11520*m*xl1^4+11520*m*xl2*...\n    xl1^3+6*hbar^2)*x(i)^5+(2880*m*xl1^5-2880*m*xl2*xl1^4-60*hbar^2*xl1+54*hbar^2*...\n    xl2)*x(i)^4+(108*hbar^2*xl1^2-108*hbar^2*xl2*xl1)*x(i)^3+(-132*hbar^2*xl1^3+132*...\n    hbar^2*xl2*xl1^2)*x(i)^2+(78*hbar^2*xl1^4-78*hbar^2*xl2*xl1^3)*x(i)+(-18*hbar^2*...\n    xl1^5+18*hbar^2*xl2*xl1^4)))*xr2+(((-2880*m*xl1+2880*m*xl2)*x(i)^4+(11520*m*...\n    xl1^2-11520*m*xl2*xl1)*x(i)^3+(-17280*m*xl1^3+17280*m*xl2*xl1^2)*x(i)^2+(11520*...\n    m*xl1^4-11520*m*xl2*xl1^3-6*hbar^2)*x(i)+(-2880*m*xl1^5+2880*m*xl2*xl1^4+24*...\n    hbar^2*xl1-18*hbar^2*xl2))*xr1^5+((11520*m*xl1-11520*m*xl2)*x(i)^5+(-46080*m*...\n    xl1^2+46080*m*xl2*xl1)*x(i)^4+(69120*m*xl1^3-69120*m*xl2*xl1^2)*x(i)^3+(-46080*...\n    m*xl1^4+46080*m*xl2*xl1^3+24*hbar^2)*x(i)^2+(11520*m*xl1^5-11520*m*xl2*...\n    xl1^4-102*hbar^2*xl1+78*hbar^2*xl2)*x(i)+(6*hbar^2*xl1^2-6*hbar^2*xl2*xl1))*...\n    xr1^4+((-17280*m*xl1+17280*m*xl2)*x(i)^6+(69120*m*xl1^2-69120*m*xl2*xl1)*...\n    x(i)^5+(-103680*m*xl1^3+103680*m*xl2*xl1^2)*x(i)^4+(69120*m*xl1^4-69120*m*xl2*...\n    xl1^3-36*hbar^2)*x(i)^3+(-17280*m*xl1^5+17280*m*xl2*xl1^4+168*hbar^2*xl1-132*...\n    hbar^2*xl2)*x(i)^2+(-30*hbar^2*xl1^2+30*hbar^2*xl2*xl1)*x(i)+(6*hbar^2*xl1^3-6*...\n    hbar^2*xl2*xl1^2))*xr1^3+((11520*m*xl1-11520*m*xl2)*x(i)^7+(-46080*m*...\n    xl1^2+46080*m*xl2*xl1)*x(i)^6+(69120*m*xl1^3-69120*m*xl2*xl1^2)*x(i)^5+(-46080*...\n    m*xl1^4+46080*m*xl2*xl1^3+24*hbar^2)*x(i)^4+(11520*m*xl1^5-11520*m*xl2*...\n    xl1^4-132*hbar^2*xl1+108*hbar^2*xl2)*x(i)^3+(60*hbar^2*xl1^2-60*hbar^2*xl2*xl1)*...\n    x(i)^2+(-30*hbar^2*xl1^3+30*hbar^2*xl2*xl1^2)*x(i)+(6*hbar^2*xl1^4-6*hbar^2*xl2*...\n    xl1^3))*xr1^2+((-2880*m*xl1+2880*m*xl2)*x(i)^8+(11520*m*xl1^2-11520*m*xl2*xl1)*...\n    x(i)^7+(-17280*m*xl1^3+17280*m*xl2*xl1^2)*x(i)^6+(11520*m*xl1^4-11520*m*xl2*...\n    xl1^3-6*hbar^2)*x(i)^5+(-2880*m*xl1^5+2880*m*xl2*xl1^4+66*hbar^2*xl1-60*hbar^2*...\n    xl2)*x(i)^4+(-132*hbar^2*xl1^2+132*hbar^2*xl2*xl1)*x(i)^3+(168*hbar^2*xl1^3-168*...\n    hbar^2*xl2*xl1^2)*x(i)^2+(-102*hbar^2*xl1^4+102*hbar^2*xl2*xl1^3)*x(i)+(24*...\n    hbar^2*xl1^5-24*hbar^2*xl2*xl1^4))*xr1+((-6*hbar^2*xl1+6*hbar^2*xl2)*x(i)^5+(24*...\n    hbar^2*xl1^2-24*hbar^2*xl2*xl1)*x(i)^4+(-36*hbar^2*xl1^3+36*hbar^2*xl2*xl1^2)*...\n    x(i)^3+(24*hbar^2*xl1^4-24*hbar^2*xl2*xl1^3)*x(i)^2+(-6*hbar^2*xl1^5+6*hbar^2*...\n    xl2*xl1^4)*x(i))))*exp(5*x(i)-5*c)^4+((((-720*m*xl1+720*m*xl2)*x(i)^4+(2880*m*...\n    xl1^2-2880*m*xl2*xl1)*x(i)^3+(-4320*m*xl1^3+4320*m*xl2*xl1^2)*x(i)^2+(2880*m*...\n    xl1^4-2880*m*xl2*xl1^3+4*hbar^2)*x(i)+(-720*m*xl1^5+720*m*xl2*xl1^4-16*hbar^2*...\n    xl1+12*hbar^2*xl2))*xr1^4+((2880*m*xl1-2880*m*xl2)*x(i)^5+(-11520*m*xl1^2+11520*...\n    m*xl2*xl1)*x(i)^4+(17280*m*xl1^3-17280*m*xl2*xl1^2)*x(i)^3+(-11520*m*...\n    xl1^4+11520*m*xl2*xl1^3-16*hbar^2)*x(i)^2+(2880*m*xl1^5-2880*m*xl2*xl1^4+68*...\n    hbar^2*xl1-52*hbar^2*xl2)*x(i)+(-4*hbar^2*xl1^2+4*hbar^2*xl2*xl1))*...\n    xr1^3+((-4320*m*xl1+4320*m*xl2)*x(i)^6+(17280*m*xl1^2-17280*m*xl2*xl1)*...\n    x(i)^5+(-25920*m*xl1^3+25920*m*xl2*xl1^2)*x(i)^4+(17280*m*xl1^4-17280*m*xl2*...\n    xl1^3+24*hbar^2)*x(i)^3+(-4320*m*xl1^5+4320*m*xl2*xl1^4-112*hbar^2*xl1+88*...\n    hbar^2*xl2)*x(i)^2+(20*hbar^2*xl1^2-20*hbar^2*xl2*xl1)*x(i)+(-4*hbar^2*xl1^3+4*...\n    hbar^2*xl2*xl1^2))*xr1^2+((2880*m*xl1-2880*m*xl2)*x(i)^7+(-11520*m*xl1^2+11520*...\n    m*xl2*xl1)*x(i)^6+(17280*m*xl1^3-17280*m*xl2*xl1^2)*x(i)^5+(-11520*m*...\n    xl1^4+11520*m*xl2*xl1^3-16*hbar^2)*x(i)^4+(2880*m*xl1^5-2880*m*xl2*xl1^4+88*...\n    hbar^2*xl1-72*hbar^2*xl2)*x(i)^3+(-40*hbar^2*xl1^2+40*hbar^2*xl2*xl1)*...\n    x(i)^2+(20*hbar^2*xl1^3-20*hbar^2*xl2*xl1^2)*x(i)+(-4*hbar^2*xl1^4+4*hbar^2*xl2*...\n    xl1^3))*xr1+((-720*m*xl1+720*m*xl2)*x(i)^8+(2880*m*xl1^2-2880*m*xl2*xl1)*...\n    x(i)^7+(-4320*m*xl1^3+4320*m*xl2*xl1^2)*x(i)^6+(2880*m*xl1^4-2880*m*xl2*xl1^3+4*...\n    hbar^2)*x(i)^5+(-720*m*xl1^5+720*m*xl2*xl1^4-40*hbar^2*xl1+36*hbar^2*xl2)*...\n    x(i)^4+(72*hbar^2*xl1^2-72*hbar^2*xl2*xl1)*x(i)^3+(-88*hbar^2*xl1^3+88*hbar^2*...\n    xl2*xl1^2)*x(i)^2+(52*hbar^2*xl1^4-52*hbar^2*xl2*xl1^3)*x(i)+(-12*hbar^2*...\n    xl1^5+12*hbar^2*xl2*xl1^4)))*xr2+(((720*m*xl1-720*m*xl2)*x(i)^4+(-2880*m*...\n    xl1^2+2880*m*xl2*xl1)*x(i)^3+(4320*m*xl1^3-4320*m*xl2*xl1^2)*x(i)^2+(-2880*m*...\n    xl1^4+2880*m*xl2*xl1^3-4*hbar^2)*x(i)+(720*m*xl1^5-720*m*xl2*xl1^4+16*hbar^2*...\n    xl1-12*hbar^2*xl2))*xr1^5+((-2880*m*xl1+2880*m*xl2)*x(i)^5+(11520*m*xl1^2-11520*...\n    m*xl2*xl1)*x(i)^4+(-17280*m*xl1^3+17280*m*xl2*xl1^2)*x(i)^3+(11520*m*...\n    xl1^4-11520*m*xl2*xl1^3+16*hbar^2)*x(i)^2+(-2880*m*xl1^5+2880*m*xl2*xl1^4-68*...\n    hbar^2*xl1+52*hbar^2*xl2)*x(i)+(4*hbar^2*xl1^2-4*hbar^2*xl2*xl1))*xr1^4+((4320*...\n    m*xl1-4320*m*xl2)*x(i)^6+(-17280*m*xl1^2+17280*m*xl2*xl1)*x(i)^5+(25920*m*...\n    xl1^3-25920*m*xl2*xl1^2)*x(i)^4+(-17280*m*xl1^4+17280*m*xl2*xl1^3-24*hbar^2)*...\n    x(i)^3+(4320*m*xl1^5-4320*m*xl2*xl1^4+112*hbar^2*xl1-88*hbar^2*xl2)*x(i)^2+(-20*...\n    hbar^2*xl1^2+20*hbar^2*xl2*xl1)*x(i)+(4*hbar^2*xl1^3-4*hbar^2*xl2*xl1^2))*...\n    xr1^3+((-2880*m*xl1+2880*m*xl2)*x(i)^7+(11520*m*xl1^2-11520*m*xl2*xl1)*...\n    x(i)^6+(-17280*m*xl1^3+17280*m*xl2*xl1^2)*x(i)^5+(11520*m*xl1^4-11520*m*xl2*...\n    xl1^3+16*hbar^2)*x(i)^4+(-2880*m*xl1^5+2880*m*xl2*xl1^4-88*hbar^2*xl1+72*hbar^2*...\n    xl2)*x(i)^3+(40*hbar^2*xl1^2-40*hbar^2*xl2*xl1)*x(i)^2+(-20*hbar^2*xl1^3+20*...\n    hbar^2*xl2*xl1^2)*x(i)+(4*hbar^2*xl1^4-4*hbar^2*xl2*xl1^3))*xr1^2+((720*m*...\n    xl1-720*m*xl2)*x(i)^8+(-2880*m*xl1^2+2880*m*xl2*xl1)*x(i)^7+(4320*m*xl1^3-4320*...\n    m*xl2*xl1^2)*x(i)^6+(-2880*m*xl1^4+2880*m*xl2*xl1^3-4*hbar^2)*x(i)^5+(720*m*...\n    xl1^5-720*m*xl2*xl1^4+44*hbar^2*xl1-40*hbar^2*xl2)*x(i)^4+(-88*hbar^2*xl1^2+88*...\n    hbar^2*xl2*xl1)*x(i)^3+(112*hbar^2*xl1^3-112*hbar^2*xl2*xl1^2)*x(i)^2+(-68*...\n    hbar^2*xl1^4+68*hbar^2*xl2*xl1^3)*x(i)+(16*hbar^2*xl1^5-16*hbar^2*xl2*xl1^4))*...\n    xr1+((-4*hbar^2*xl1+4*hbar^2*xl2)*x(i)^5+(16*hbar^2*xl1^2-16*hbar^2*xl2*xl1)*...\n    x(i)^4+(-24*hbar^2*xl1^3+24*hbar^2*xl2*xl1^2)*x(i)^3+(16*hbar^2*xl1^4-16*hbar^2*...\n    xl2*xl1^3)*x(i)^2+(-4*hbar^2*xl1^5+4*hbar^2*xl2*xl1^4)*x(i))))*exp(5*x(i)-5*...\n    c)^2+(((hbar^2*x(i)+(-4*hbar^2*xl1+3*hbar^2*xl2))*xr1^4+(-4*hbar^2*x(i)^2+(17*...\n    hbar^2*xl1-13*hbar^2*xl2)*x(i)+(-1*hbar^2*xl1^2+hbar^2*xl2*xl1))*xr1^3+(6*...\n    hbar^2*x(i)^3+(-28*hbar^2*xl1+22*hbar^2*xl2)*x(i)^2+(5*hbar^2*xl1^2-5*hbar^2*...\n    xl2*xl1)*x(i)+(-1*hbar^2*xl1^3+hbar^2*xl2*xl1^2))*xr1^2+(-4*hbar^2*x(i)^4+(22*...\n    hbar^2*xl1-18*hbar^2*xl2)*x(i)^3+(-10*hbar^2*xl1^2+10*hbar^2*xl2*xl1)*x(i)^2+(5*...\n    hbar^2*xl1^3-5*hbar^2*xl2*xl1^2)*x(i)+(-1*hbar^2*xl1^4+hbar^2*xl2*xl1^3))*...\n    xr1+(hbar^2*x(i)^5+(-10*hbar^2*xl1+9*hbar^2*xl2)*x(i)^4+(18*hbar^2*xl1^2-18*...\n    hbar^2*xl2*xl1)*x(i)^3+(-22*hbar^2*xl1^3+22*hbar^2*xl2*xl1^2)*x(i)^2+(13*hbar^2*...\n    xl1^4-13*hbar^2*xl2*xl1^3)*x(i)+(-3*hbar^2*xl1^5+3*hbar^2*xl2*xl1^4)))*xr2+((-1*...\n    hbar^2*x(i)+(4*hbar^2*xl1-3*hbar^2*xl2))*xr1^5+(4*hbar^2*x(i)^2+(-17*hbar^2*...\n    xl1+13*hbar^2*xl2)*x(i)+(hbar^2*xl1^2-1*hbar^2*xl2*xl1))*xr1^4+(-6*hbar^2*...\n    x(i)^3+(28*hbar^2*xl1-22*hbar^2*xl2)*x(i)^2+(-5*hbar^2*xl1^2+5*hbar^2*xl2*xl1)*...\n    x(i)+(hbar^2*xl1^3-1*hbar^2*xl2*xl1^2))*xr1^3+(4*hbar^2*x(i)^4+(-22*hbar^2*...\n    xl1+18*hbar^2*xl2)*x(i)^3+(10*hbar^2*xl1^2-10*hbar^2*xl2*xl1)*x(i)^2+(-5*hbar^2*...\n    xl1^3+5*hbar^2*xl2*xl1^2)*x(i)+(hbar^2*xl1^4-1*hbar^2*xl2*xl1^3))*xr1^2+(-1*...\n    hbar^2*x(i)^5+(11*hbar^2*xl1-10*hbar^2*xl2)*x(i)^4+(-22*hbar^2*xl1^2+22*hbar^2*...\n    xl2*xl1)*x(i)^3+(28*hbar^2*xl1^3-28*hbar^2*xl2*xl1^2)*x(i)^2+(-17*hbar^2*...\n    xl1^4+17*hbar^2*xl2*xl1^3)*x(i)+(4*hbar^2*xl1^5-4*hbar^2*xl2*xl1^4))*xr1+((-1*...\n    hbar^2*xl1+hbar^2*xl2)*x(i)^5+(4*hbar^2*xl1^2-4*hbar^2*xl2*xl1)*x(i)^4+(-6*...\n    hbar^2*xl1^3+6*hbar^2*xl2*xl1^2)*x(i)^3+(4*hbar^2*xl1^4-4*hbar^2*xl2*xl1^3)*...\n    x(i)^2+(-1*hbar^2*xl1^5+hbar^2*xl2*xl1^4)*x(i)))))/(((((2*m^2*xl1-2*m^2*xl2)*...\n    x(i)^4+(-8*m^2*xl1^2+8*m^2*xl2*xl1)*x(i)^3+(12*m^2*xl1^3-12*m^2*xl2*xl1^2)*...\n    x(i)^2+(-8*m^2*xl1^4+8*m^2*xl2*xl1^3)*x(i)+(2*m^2*xl1^5-2*m^2*xl2*xl1^4))*...\n    xr1^4+((-8*m^2*xl1+8*m^2*xl2)*x(i)^5+(32*m^2*xl1^2-32*m^2*xl2*xl1)*x(i)^4+(-48*...\n    m^2*xl1^3+48*m^2*xl2*xl1^2)*x(i)^3+(32*m^2*xl1^4-32*m^2*xl2*xl1^3)*x(i)^2+(-8*...\n    m^2*xl1^5+8*m^2*xl2*xl1^4)*x(i))*xr1^3+((12*m^2*xl1-12*m^2*xl2)*x(i)^6+(-48*m^2*...\n    xl1^2+48*m^2*xl2*xl1)*x(i)^5+(72*m^2*xl1^3-72*m^2*xl2*xl1^2)*x(i)^4+(-48*m^2*...\n    xl1^4+48*m^2*xl2*xl1^3)*x(i)^3+(12*m^2*xl1^5-12*m^2*xl2*xl1^4)*x(i)^2)*...\n    xr1^2+((-8*m^2*xl1+8*m^2*xl2)*x(i)^7+(32*m^2*xl1^2-32*m^2*xl2*xl1)*x(i)^6+(-48*...\n    m^2*xl1^3+48*m^2*xl2*xl1^2)*x(i)^5+(32*m^2*xl1^4-32*m^2*xl2*xl1^3)*x(i)^4+(-8*...\n    m^2*xl1^5+8*m^2*xl2*xl1^4)*x(i)^3)*xr1+((2*m^2*xl1-2*m^2*xl2)*x(i)^8+(-8*m^2*...\n    xl1^2+8*m^2*xl2*xl1)*x(i)^7+(12*m^2*xl1^3-12*m^2*xl2*xl1^2)*x(i)^6+(-8*m^2*...\n    xl1^4+8*m^2*xl2*xl1^3)*x(i)^5+(2*m^2*xl1^5-2*m^2*xl2*xl1^4)*x(i)^4))*xr2+(((-2*...\n    m^2*xl1+2*m^2*xl2)*x(i)^4+(8*m^2*xl1^2-8*m^2*xl2*xl1)*x(i)^3+(-12*m^2*xl1^3+12*...\n    m^2*xl2*xl1^2)*x(i)^2+(8*m^2*xl1^4-8*m^2*xl2*xl1^3)*x(i)+(-2*m^2*xl1^5+2*m^2*...\n    xl2*xl1^4))*xr1^5+((8*m^2*xl1-8*m^2*xl2)*x(i)^5+(-32*m^2*xl1^2+32*m^2*xl2*xl1)*...\n    x(i)^4+(48*m^2*xl1^3-48*m^2*xl2*xl1^2)*x(i)^3+(-32*m^2*xl1^4+32*m^2*xl2*xl1^3)*...\n    x(i)^2+(8*m^2*xl1^5-8*m^2*xl2*xl1^4)*x(i))*xr1^4+((-12*m^2*xl1+12*m^2*xl2)*...\n    x(i)^6+(48*m^2*xl1^2-48*m^2*xl2*xl1)*x(i)^5+(-72*m^2*xl1^3+72*m^2*xl2*xl1^2)*...\n    x(i)^4+(48*m^2*xl1^4-48*m^2*xl2*xl1^3)*x(i)^3+(-12*m^2*xl1^5+12*m^2*xl2*xl1^4)*...\n    x(i)^2)*xr1^3+((8*m^2*xl1-8*m^2*xl2)*x(i)^7+(-32*m^2*xl1^2+32*m^2*xl2*xl1)*...\n    x(i)^6+(48*m^2*xl1^3-48*m^2*xl2*xl1^2)*x(i)^5+(-32*m^2*xl1^4+32*m^2*xl2*xl1^3)*...\n    x(i)^4+(8*m^2*xl1^5-8*m^2*xl2*xl1^4)*x(i)^3)*xr1^2+((-2*m^2*xl1+2*m^2*xl2)*...\n    x(i)^8+(8*m^2*xl1^2-8*m^2*xl2*xl1)*x(i)^7+(-12*m^2*xl1^3+12*m^2*xl2*xl1^2)*...\n    x(i)^6+(8*m^2*xl1^4-8*m^2*xl2*xl1^3)*x(i)^5+(-2*m^2*xl1^5+2*m^2*xl2*xl1^4)*...\n    x(i)^4)*xr1))*exp(5*x(i)-5*c)^8+((((8*m^2*xl1-8*m^2*xl2)*x(i)^4+(-32*m^2*...\n    xl1^2+32*m^2*xl2*xl1)*x(i)^3+(48*m^2*xl1^3-48*m^2*xl2*xl1^2)*x(i)^2+(-32*m^2*...\n    xl1^4+32*m^2*xl2*xl1^3)*x(i)+(8*m^2*xl1^5-8*m^2*xl2*xl1^4))*xr1^4+((-32*m^2*...\n    xl1+32*m^2*xl2)*x(i)^5+(128*m^2*xl1^2-128*m^2*xl2*xl1)*x(i)^4+(-192*m^2*...\n    xl1^3+192*m^2*xl2*xl1^2)*x(i)^3+(128*m^2*xl1^4-128*m^2*xl2*xl1^3)*x(i)^2+(-32*...\n    m^2*xl1^5+32*m^2*xl2*xl1^4)*x(i))*xr1^3+((48*m^2*xl1-48*m^2*xl2)*x(i)^6+(-192*...\n    m^2*xl1^2+192*m^2*xl2*xl1)*x(i)^5+(288*m^2*xl1^3-288*m^2*xl2*xl1^2)*...\n    x(i)^4+(-192*m^2*xl1^4+192*m^2*xl2*xl1^3)*x(i)^3+(48*m^2*xl1^5-48*m^2*xl2*...\n    xl1^4)*x(i)^2)*xr1^2+((-32*m^2*xl1+32*m^2*xl2)*x(i)^7+(128*m^2*xl1^2-128*m^2*...\n    xl2*xl1)*x(i)^6+(-192*m^2*xl1^3+192*m^2*xl2*xl1^2)*x(i)^5+(128*m^2*xl1^4-128*...\n    m^2*xl2*xl1^3)*x(i)^4+(-32*m^2*xl1^5+32*m^2*xl2*xl1^4)*x(i)^3)*xr1+((8*m^2*...\n    xl1-8*m^2*xl2)*x(i)^8+(-32*m^2*xl1^2+32*m^2*xl2*xl1)*x(i)^7+(48*m^2*xl1^3-48*...\n    m^2*xl2*xl1^2)*x(i)^6+(-32*m^2*xl1^4+32*m^2*xl2*xl1^3)*x(i)^5+(8*m^2*xl1^5-8*...\n    m^2*xl2*xl1^4)*x(i)^4))*xr2+(((-8*m^2*xl1+8*m^2*xl2)*x(i)^4+(32*m^2*xl1^2-32*...\n    m^2*xl2*xl1)*x(i)^3+(-48*m^2*xl1^3+48*m^2*xl2*xl1^2)*x(i)^2+(32*m^2*xl1^4-32*...\n    m^2*xl2*xl1^3)*x(i)+(-8*m^2*xl1^5+8*m^2*xl2*xl1^4))*xr1^5+((32*m^2*xl1-32*m^2*...\n    xl2)*x(i)^5+(-128*m^2*xl1^2+128*m^2*xl2*xl1)*x(i)^4+(192*m^2*xl1^3-192*m^2*xl2*...\n    xl1^2)*x(i)^3+(-128*m^2*xl1^4+128*m^2*xl2*xl1^3)*x(i)^2+(32*m^2*xl1^5-32*m^2*...\n    xl2*xl1^4)*x(i))*xr1^4+((-48*m^2*xl1+48*m^2*xl2)*x(i)^6+(192*m^2*xl1^2-192*m^2*...\n    xl2*xl1)*x(i)^5+(-288*m^2*xl1^3+288*m^2*xl2*xl1^2)*x(i)^4+(192*m^2*xl1^4-192*...\n    m^2*xl2*xl1^3)*x(i)^3+(-48*m^2*xl1^5+48*m^2*xl2*xl1^4)*x(i)^2)*xr1^3+((32*m^2*...\n    xl1-32*m^2*xl2)*x(i)^7+(-128*m^2*xl1^2+128*m^2*xl2*xl1)*x(i)^6+(192*m^2*...\n    xl1^3-192*m^2*xl2*xl1^2)*x(i)^5+(-128*m^2*xl1^4+128*m^2*xl2*xl1^3)*x(i)^4+(32*...\n    m^2*xl1^5-32*m^2*xl2*xl1^4)*x(i)^3)*xr1^2+((-8*m^2*xl1+8*m^2*xl2)*x(i)^8+(32*...\n    m^2*xl1^2-32*m^2*xl2*xl1)*x(i)^7+(-48*m^2*xl1^3+48*m^2*xl2*xl1^2)*x(i)^6+(32*...\n    m^2*xl1^4-32*m^2*xl2*xl1^3)*x(i)^5+(-8*m^2*xl1^5+8*m^2*xl2*xl1^4)*x(i)^4)*xr1))*...\n    exp(5*x(i)-5*c)^6+((((12*m^2*xl1-12*m^2*xl2)*x(i)^4+(-48*m^2*xl1^2+48*m^2*xl2*...\n    xl1)*x(i)^3+(72*m^2*xl1^3-72*m^2*xl2*xl1^2)*x(i)^2+(-48*m^2*xl1^4+48*m^2*xl2*...\n    xl1^3)*x(i)+(12*m^2*xl1^5-12*m^2*xl2*xl1^4))*xr1^4+((-48*m^2*xl1+48*m^2*xl2)*...\n    x(i)^5+(192*m^2*xl1^2-192*m^2*xl2*xl1)*x(i)^4+(-288*m^2*xl1^3+288*m^2*xl2*...\n    xl1^2)*x(i)^3+(192*m^2*xl1^4-192*m^2*xl2*xl1^3)*x(i)^2+(-48*m^2*xl1^5+48*m^2*...\n    xl2*xl1^4)*x(i))*xr1^3+((72*m^2*xl1-72*m^2*xl2)*x(i)^6+(-288*m^2*xl1^2+288*m^2*...\n    xl2*xl1)*x(i)^5+(432*m^2*xl1^3-432*m^2*xl2*xl1^2)*x(i)^4+(-288*m^2*xl1^4+288*...\n    m^2*xl2*xl1^3)*x(i)^3+(72*m^2*xl1^5-72*m^2*xl2*xl1^4)*x(i)^2)*xr1^2+((-48*m^2*...\n    xl1+48*m^2*xl2)*x(i)^7+(192*m^2*xl1^2-192*m^2*xl2*xl1)*x(i)^6+(-288*m^2*...\n    xl1^3+288*m^2*xl2*xl1^2)*x(i)^5+(192*m^2*xl1^4-192*m^2*xl2*xl1^3)*x(i)^4+(-48*...\n    m^2*xl1^5+48*m^2*xl2*xl1^4)*x(i)^3)*xr1+((12*m^2*xl1-12*m^2*xl2)*x(i)^8+(-48*...\n    m^2*xl1^2+48*m^2*xl2*xl1)*x(i)^7+(72*m^2*xl1^3-72*m^2*xl2*xl1^2)*x(i)^6+(-48*...\n    m^2*xl1^4+48*m^2*xl2*xl1^3)*x(i)^5+(12*m^2*xl1^5-12*m^2*xl2*xl1^4)*x(i)^4))*...\n    xr2+(((-12*m^2*xl1+12*m^2*xl2)*x(i)^4+(48*m^2*xl1^2-48*m^2*xl2*xl1)*x(i)^3+(-72*...\n    m^2*xl1^3+72*m^2*xl2*xl1^2)*x(i)^2+(48*m^2*xl1^4-48*m^2*xl2*xl1^3)*x(i)+(-12*...\n    m^2*xl1^5+12*m^2*xl2*xl1^4))*xr1^5+((48*m^2*xl1-48*m^2*xl2)*x(i)^5+(-192*m^2*...\n    xl1^2+192*m^2*xl2*xl1)*x(i)^4+(288*m^2*xl1^3-288*m^2*xl2*xl1^2)*x(i)^3+(-192*...\n    m^2*xl1^4+192*m^2*xl2*xl1^3)*x(i)^2+(48*m^2*xl1^5-48*m^2*xl2*xl1^4)*x(i))*...\n    xr1^4+((-72*m^2*xl1+72*m^2*xl2)*x(i)^6+(288*m^2*xl1^2-288*m^2*xl2*xl1)*...\n    x(i)^5+(-432*m^2*xl1^3+432*m^2*xl2*xl1^2)*x(i)^4+(288*m^2*xl1^4-288*m^2*xl2*...\n    xl1^3)*x(i)^3+(-72*m^2*xl1^5+72*m^2*xl2*xl1^4)*x(i)^2)*xr1^3+((48*m^2*xl1-48*...\n    m^2*xl2)*x(i)^7+(-192*m^2*xl1^2+192*m^2*xl2*xl1)*x(i)^6+(288*m^2*xl1^3-288*m^2*...\n    xl2*xl1^2)*x(i)^5+(-192*m^2*xl1^4+192*m^2*xl2*xl1^3)*x(i)^4+(48*m^2*xl1^5-48*...\n    m^2*xl2*xl1^4)*x(i)^3)*xr1^2+((-12*m^2*xl1+12*m^2*xl2)*x(i)^8+(48*m^2*xl1^2-48*...\n    m^2*xl2*xl1)*x(i)^7+(-72*m^2*xl1^3+72*m^2*xl2*xl1^2)*x(i)^6+(48*m^2*xl1^4-48*...\n    m^2*xl2*xl1^3)*x(i)^5+(-12*m^2*xl1^5+12*m^2*xl2*xl1^4)*x(i)^4)*xr1))*exp(5*...\n    x(i)-5*c)^4+((((8*m^2*xl1-8*m^2*xl2)*x(i)^4+(-32*m^2*xl1^2+32*m^2*xl2*xl1)*...\n    x(i)^3+(48*m^2*xl1^3-48*m^2*xl2*xl1^2)*x(i)^2+(-32*m^2*xl1^4+32*m^2*xl2*xl1^3)*...\n    x(i)+(8*m^2*xl1^5-8*m^2*xl2*xl1^4))*xr1^4+((-32*m^2*xl1+32*m^2*xl2)*x(i)^5+(128*...\n    m^2*xl1^2-128*m^2*xl2*xl1)*x(i)^4+(-192*m^2*xl1^3+192*m^2*xl2*xl1^2)*...\n    x(i)^3+(128*m^2*xl1^4-128*m^2*xl2*xl1^3)*x(i)^2+(-32*m^2*xl1^5+32*m^2*xl2*...\n    xl1^4)*x(i))*xr1^3+((48*m^2*xl1-48*m^2*xl2)*x(i)^6+(-192*m^2*xl1^2+192*m^2*xl2*...\n    xl1)*x(i)^5+(288*m^2*xl1^3-288*m^2*xl2*xl1^2)*x(i)^4+(-192*m^2*xl1^4+192*m^2*...\n    xl2*xl1^3)*x(i)^3+(48*m^2*xl1^5-48*m^2*xl2*xl1^4)*x(i)^2)*xr1^2+((-32*m^2*...\n    xl1+32*m^2*xl2)*x(i)^7+(128*m^2*xl1^2-128*m^2*xl2*xl1)*x(i)^6+(-192*m^2*...\n    xl1^3+192*m^2*xl2*xl1^2)*x(i)^5+(128*m^2*xl1^4-128*m^2*xl2*xl1^3)*x(i)^4+(-32*...\n    m^2*xl1^5+32*m^2*xl2*xl1^4)*x(i)^3)*xr1+((8*m^2*xl1-8*m^2*xl2)*x(i)^8+(-32*m^2*...\n    xl1^2+32*m^2*xl2*xl1)*x(i)^7+(48*m^2*xl1^3-48*m^2*xl2*xl1^2)*x(i)^6+(-32*m^2*...\n    xl1^4+32*m^2*xl2*xl1^3)*x(i)^5+(8*m^2*xl1^5-8*m^2*xl2*xl1^4)*x(i)^4))*xr2+(((-8*...\n    m^2*xl1+8*m^2*xl2)*x(i)^4+(32*m^2*xl1^2-32*m^2*xl2*xl1)*x(i)^3+(-48*m^2*...\n    xl1^3+48*m^2*xl2*xl1^2)*x(i)^2+(32*m^2*xl1^4-32*m^2*xl2*xl1^3)*x(i)+(-8*m^2*...\n    xl1^5+8*m^2*xl2*xl1^4))*xr1^5+((32*m^2*xl1-32*m^2*xl2)*x(i)^5+(-128*m^2*...\n    xl1^2+128*m^2*xl2*xl1)*x(i)^4+(192*m^2*xl1^3-192*m^2*xl2*xl1^2)*x(i)^3+(-128*...\n    m^2*xl1^4+128*m^2*xl2*xl1^3)*x(i)^2+(32*m^2*xl1^5-32*m^2*xl2*xl1^4)*x(i))*...\n    xr1^4+((-48*m^2*xl1+48*m^2*xl2)*x(i)^6+(192*m^2*xl1^2-192*m^2*xl2*xl1)*...\n    x(i)^5+(-288*m^2*xl1^3+288*m^2*xl2*xl1^2)*x(i)^4+(192*m^2*xl1^4-192*m^2*xl2*...\n    xl1^3)*x(i)^3+(-48*m^2*xl1^5+48*m^2*xl2*xl1^4)*x(i)^2)*xr1^3+((32*m^2*xl1-32*...\n    m^2*xl2)*x(i)^7+(-128*m^2*xl1^2+128*m^2*xl2*xl1)*x(i)^6+(192*m^2*xl1^3-192*m^2*...\n    xl2*xl1^2)*x(i)^5+(-128*m^2*xl1^4+128*m^2*xl2*xl1^3)*x(i)^4+(32*m^2*xl1^5-32*...\n    m^2*xl2*xl1^4)*x(i)^3)*xr1^2+((-8*m^2*xl1+8*m^2*xl2)*x(i)^8+(32*m^2*xl1^2-32*...\n    m^2*xl2*xl1)*x(i)^7+(-48*m^2*xl1^3+48*m^2*xl2*xl1^2)*x(i)^6+(32*m^2*xl1^4-32*...\n    m^2*xl2*xl1^3)*x(i)^5+(-8*m^2*xl1^5+8*m^2*xl2*xl1^4)*x(i)^4)*xr1))*exp(5*x(i)-5*...\n    c)^2+((((2*m^2*xl1-2*m^2*xl2)*x(i)^4+(-8*m^2*xl1^2+8*m^2*xl2*xl1)*x(i)^3+(12*...\n    m^2*xl1^3-12*m^2*xl2*xl1^2)*x(i)^2+(-8*m^2*xl1^4+8*m^2*xl2*xl1^3)*x(i)+(2*m^2*...\n    xl1^5-2*m^2*xl2*xl1^4))*xr1^4+((-8*m^2*xl1+8*m^2*xl2)*x(i)^5+(32*m^2*xl1^2-32*...\n    m^2*xl2*xl1)*x(i)^4+(-48*m^2*xl1^3+48*m^2*xl2*xl1^2)*x(i)^3+(32*m^2*xl1^4-32*...\n    m^2*xl2*xl1^3)*x(i)^2+(-8*m^2*xl1^5+8*m^2*xl2*xl1^4)*x(i))*xr1^3+((12*m^2*...\n    xl1-12*m^2*xl2)*x(i)^6+(-48*m^2*xl1^2+48*m^2*xl2*xl1)*x(i)^5+(72*m^2*xl1^3-72*...\n    m^2*xl2*xl1^2)*x(i)^4+(-48*m^2*xl1^4+48*m^2*xl2*xl1^3)*x(i)^3+(12*m^2*xl1^5-12*...\n    m^2*xl2*xl1^4)*x(i)^2)*xr1^2+((-8*m^2*xl1+8*m^2*xl2)*x(i)^7+(32*m^2*xl1^2-32*...\n    m^2*xl2*xl1)*x(i)^6+(-48*m^2*xl1^3+48*m^2*xl2*xl1^2)*x(i)^5+(32*m^2*xl1^4-32*...\n    m^2*xl2*xl1^3)*x(i)^4+(-8*m^2*xl1^5+8*m^2*xl2*xl1^4)*x(i)^3)*xr1+((2*m^2*xl1-2*...\n    m^2*xl2)*x(i)^8+(-8*m^2*xl1^2+8*m^2*xl2*xl1)*x(i)^7+(12*m^2*xl1^3-12*m^2*xl2*...\n    xl1^2)*x(i)^6+(-8*m^2*xl1^4+8*m^2*xl2*xl1^3)*x(i)^5+(2*m^2*xl1^5-2*m^2*xl2*...\n    xl1^4)*x(i)^4))*xr2+(((-2*m^2*xl1+2*m^2*xl2)*x(i)^4+(8*m^2*xl1^2-8*m^2*xl2*xl1)*...\n    x(i)^3+(-12*m^2*xl1^3+12*m^2*xl2*xl1^2)*x(i)^2+(8*m^2*xl1^4-8*m^2*xl2*xl1^3)*...\n    x(i)+(-2*m^2*xl1^5+2*m^2*xl2*xl1^4))*xr1^5+((8*m^2*xl1-8*m^2*xl2)*x(i)^5+(-32*...\n    m^2*xl1^2+32*m^2*xl2*xl1)*x(i)^4+(48*m^2*xl1^3-48*m^2*xl2*xl1^2)*x(i)^3+(-32*...\n    m^2*xl1^4+32*m^2*xl2*xl1^3)*x(i)^2+(8*m^2*xl1^5-8*m^2*xl2*xl1^4)*x(i))*...\n    xr1^4+((-12*m^2*xl1+12*m^2*xl2)*x(i)^6+(48*m^2*xl1^2-48*m^2*xl2*xl1)*...\n    x(i)^5+(-72*m^2*xl1^3+72*m^2*xl2*xl1^2)*x(i)^4+(48*m^2*xl1^4-48*m^2*xl2*xl1^3)*...\n    x(i)^3+(-12*m^2*xl1^5+12*m^2*xl2*xl1^4)*x(i)^2)*xr1^3+((8*m^2*xl1-8*m^2*xl2)*...\n    x(i)^7+(-32*m^2*xl1^2+32*m^2*xl2*xl1)*x(i)^6+(48*m^2*xl1^3-48*m^2*xl2*xl1^2)*...\n    x(i)^5+(-32*m^2*xl1^4+32*m^2*xl2*xl1^3)*x(i)^4+(8*m^2*xl1^5-8*m^2*xl2*xl1^4)*...\n    x(i)^3)*xr1^2+((-2*m^2*xl1+2*m^2*xl2)*x(i)^8+(8*m^2*xl1^2-8*m^2*xl2*xl1)*...\n    x(i)^7+(-12*m^2*xl1^3+12*m^2*xl2*xl1^2)*x(i)^6+(8*m^2*xl1^4-8*m^2*xl2*xl1^3)*...\n    x(i)^5+(-2*m^2*xl1^5+2*m^2*xl2*xl1^4)*x(i)^4)*xr1)));\nendfunction\n"}︡{"stdout":"\n"}︡
︠41cbe031-3839-47c0-87ad-85ea54e90a75︠
%sage print fricas2octave('Jp1','jac1(i,1)')
︡eb23c98b-501c-4017-a680-3560ec55f4c6︡{"stdout":"function result=Jp1(x,i)\n  global l2 l1 p1 p2;\n  global N m hbar a b c;\n  if (i-2<1)\n    xl2=l2;\n  else\n    xl2=x(i-2);\n  endif;\n  if (i-1<1)\n    xl1=l1;\n  else\n    xl1=x(i-1);\n  endif;\n  if (i+2>N)\n    xr2=p2;\n  else\n    xr2=x(i+2);\n  endif;\n  if (i+1>N)\n    xr1=p1;\n  else\n    xr1=x(i+1);\n  endif;\n  result=((hbar^2*xr1^2+(-4*hbar^2*x(i)+2*hbar^2*xl1)*xr1+(9*hbar^2*x(i)^2-14*hbar^2*xl1*...\n    x(i)+6*hbar^2*xl1^2))*xr2^2+(-2*hbar^2*xr1^3+(8*hbar^2*x(i)-4*hbar^2*xl1)*...\n    xr1^2+(-20*hbar^2*x(i)^2+32*hbar^2*xl1*x(i)-14*hbar^2*xl1^2)*xr1+(2*hbar^2*...\n    x(i)^3-4*hbar^2*xl1*x(i)^2+2*hbar^2*xl1^2*x(i)))*xr2+(hbar^2*xr1^4+(-4*hbar^2*...\n    x(i)+2*hbar^2*xl1)*xr1^3+(12*hbar^2*x(i)^2-20*hbar^2*xl1*x(i)+9*hbar^2*xl1^2)*...\n    xr1^2+(-4*hbar^2*x(i)^3+8*hbar^2*xl1*x(i)^2-4*hbar^2*xl1^2*x(i))*xr1+(hbar^2*...\n    x(i)^4-2*hbar^2*xl1*x(i)^3+hbar^2*xl1^2*x(i)^2)))/(((4*m^2*x(i)^2-8*m^2*xl1*...\n    x(i)+4*m^2*xl1^2)*xr1^4+(-16*m^2*x(i)^3+32*m^2*xl1*x(i)^2-16*m^2*xl1^2*x(i))*...\n    xr1^3+(24*m^2*x(i)^4-48*m^2*xl1*x(i)^3+24*m^2*xl1^2*x(i)^2)*xr1^2+(-16*m^2*...\n    x(i)^5+32*m^2*xl1*x(i)^4-16*m^2*xl1^2*x(i)^3)*xr1+(4*m^2*x(i)^6-8*m^2*xl1*...\n    x(i)^5+4*m^2*xl1^2*x(i)^4))*xr2^2+((-8*m^2*x(i)^2+16*m^2*xl1*x(i)-8*m^2*xl1^2)*...\n    xr1^5+(32*m^2*x(i)^3-64*m^2*xl1*x(i)^2+32*m^2*xl1^2*x(i))*xr1^4+(-48*m^2*...\n    x(i)^4+96*m^2*xl1*x(i)^3-48*m^2*xl1^2*x(i)^2)*xr1^3+(32*m^2*x(i)^5-64*m^2*xl1*...\n    x(i)^4+32*m^2*xl1^2*x(i)^3)*xr1^2+(-8*m^2*x(i)^6+16*m^2*xl1*x(i)^5-8*m^2*xl1^2*...\n    x(i)^4)*xr1)*xr2+((4*m^2*x(i)^2-8*m^2*xl1*x(i)+4*m^2*xl1^2)*xr1^6+(-16*m^2*...\n    x(i)^3+32*m^2*xl1*x(i)^2-16*m^2*xl1^2*x(i))*xr1^5+(24*m^2*x(i)^4-48*m^2*xl1*...\n    x(i)^3+24*m^2*xl1^2*x(i)^2)*xr1^4+(-16*m^2*x(i)^5+32*m^2*xl1*x(i)^4-16*m^2*...\n    xl1^2*x(i)^3)*xr1^3+(4*m^2*x(i)^6-8*m^2*xl1*x(i)^5+4*m^2*xl1^2*x(i)^4)*xr1^2));\nendfunction\n"}︡{"stdout":"\n"}︡
︠03872e3f-2596-43d7-8542-f6298ff7b171︠
%sage print fricas2octave('Jp2','jac1(i,2)')
︡fb6fe02d-b859-4d06-b910-63da20c5463c︡{"stdout":"function result=Jp2(x,i)\n  global l2 l1 p1 p2;\n  global N m hbar a b c;\n  if (i-2<1)\n    xl2=l2;\n  else\n    xl2=x(i-2);\n  endif;\n  if (i-1<1)\n    xl1=l1;\n  else\n    xl1=x(i-1);\n  endif;\n  if (i+2>N)\n    xr2=p2;\n  else\n    xr2=x(i+2);\n  endif;\n  if (i+1>N)\n    xr1=p1;\n  else\n    xr1=x(i+1);\n  endif;\n  result=(-1*hbar^2)/((4*m^2*xr1^2-8*m^2*x(i)*xr1+4*m^2*x(i)^2)*xr2^2+(-8*m^2*xr1^3+16*...\n    m^2*x(i)*xr1^2-8*m^2*x(i)^2*xr1)*xr2+(4*m^2*xr1^4-8*m^2*x(i)*xr1^3+4*m^2*x(i)^2*...\n    xr1^2));\nendfunction\n\n"}︡
︠aa670c53-778a-4c40-bded-d528dca3dd66︠
function result=jac1(x,i,j)
  global m hbar a;
  if (j==-2)
    result=Jm2(x,i);
  elseif (j==-1)
    result=Jm1(x,i);
  elseif (j==0)
    result=J0(x,i);
  elseif (j==1)
    result=Jp1(x,i);
  elseif (j==2)
    result=Jp2(x,i);
  else
    result=0;
  endif
endfunction
︡4fff4f14-6ecd-42fe-9a14-32e83f60334b︡
︠bb747973-3d17-491e-b726-9e813e9a660b︠
jac1([X0;Y0],3,2)
︡c97bef46-c318-4251-8efb-710a51d922b6︡{"stdout":"ans = -2.50144"}︡
︠95565d97-eb40-4711-89c1-dfc169cf457d︠
function result = jac0(x,i,j)
  global N m hbar a;
  if (i==j-N)
    result = 1;
  elseif (i<=N)
    result = 0;
  elseif (i<N+j-2)
    result = 0;
  else
    result = jac1(x,i-N,i-N-j);
  endif
endfunction
︡1281aa92-a777-4964-a1a5-4725aae0c210︡
︠60fb2e15-3f33-4bc4-a723-9f93f14502ee︠
jac0([X0;Y0],15,5)
︡09b35e5b-502f-440b-a38f-0a01ce95d9cd︡{"stdout":"ans = 0"}︡
︠e20d2922-0873-402d-9900-ca4c0617dfe2︠
function jac=jacm(x,t)
  global N
  jac=zeros(2*N,2*N);
  for i=1:2*N
    for j=1:2*N
      jac(i,j)=jac0(x,i,j);
    endfor
  endfor
endfunction
︡7b4c5001-4db7-439d-b6df-dd2747f197f8︡
︠7108db82-897a-428c-817b-549052d4e70di︠
%md Perform the time updates
︡69befa9e-4e7f-4e20-b8d0-776997c8362a︡{"md":"Perform the time updates"}︡
︠cc686a22-efc7-45b7-a7e0-edd808a1f9d7︠
t0 = clock ();
trec = linspace (0, 10, 240)';

#Xrec = lsode (@deq, [X0;Y0], trec)';
Xrec = lsode ({@deq,@jacm}, [X0;Y0], trec)';
elapsed_time = etime (clock (), t0)
T=size(trec,1);
lsode_options()

︡e1934e5a-7432-4d17-b914-4f7fe2ccb861︡{"stdout":"elapsed_time = 108.378\n\nOptions for LSODE include:\n\n  keyword                                             value\n  -------                                             -----\n  absolute tolerance                                  1.49012e-08\n  relative tolerance                                  1.49012e-08\n  integration method                                  stiff\n  initial step size                                   -1\n  maximum order                                       -1\n  maximum step size                                   -1\n  minimum step size                                   0\n  step limit                                          100000\n"}︡
︠4c0bf52d-6360-4147-96ad-351aa0532332︠
h = figure('visible', 'off');
plot(trec,Xrec(1:N,1:T));
saveas(h,"figure2.png");
%ylim([-2,2]);
︡9f3ed1c5-5b52-429a-822a-3c957b0b1c84︡{"stdout":"\n\n\n"}︡
︠2a01a225-6838-40cd-ae09-fb213b8832f8︠
%sage salvus.file("figure2.png")
︡074e2c40-1121-469c-bc2b-aceb0e71be60︡{"once":false,"file":{"show":true,"uuid":"02fc1c4a-ec54-4c47-b7ef-66a856c1622a","filename":"figure2.png"}}︡
︠571a2dee-9719-4f37-99e0-63fb032f2dfc︠
h = figure('visible', 'off');
%Plot the density at the end of the simulation
Dist=((Xrec(2:N,T)-Xrec(1:(N-1),T)));
Prob=(1/N)*Dist.^(-1);
plot(Xrec(2:N,T),Prob);
saveas(h,"figure3.png");
%xlim([-1.5,1.5]); ylim([0,1]);
︡2874562d-aaeb-4bc1-b5a1-1b83e378573c︡
︠86054b57-4df6-4cb2-a64d-3ad551c12cf2o︠
%sage salvus.file("figure3.png")
︡4bb456df-2130-4af4-bcd9-a0a25d4b99ca︡{"once":false,"file":{"show":true,"uuid":"d57a0b7e-ed66-403d-a63a-34f21be93d0f","filename":"figure3.png"}}︡
︠8812a223-1dd3-4db9-be60-36e71f1c46e4︠
h = figure('visible', 'off');
%Plot the density at 3/4 through the simulation
Tsamp=3*T/4;
Dist=((Xrec(2:N,Tsamp)-Xrec(1:(N-1),Tsamp)));
Prob=(1/N)*Dist.^(-1);
︡19052076-6ab0-405c-ba10-b96a8f861c5b︡
︠1dfbfacd-e79f-4adb-93d3-c2eb603b1310︠
plot(Xrec(2:N,Tsamp),Prob);
saveas(h,"figure4.png");
%xlim([-1.5,1.5]); ylim([0,1]);
︡e9c99ff3-42f4-4d1a-98df-5506fed63f6b︡{"stdout":"\n\n"}︡
︠19b50132-64cf-4a6a-b4b7-0ece8b9ed4c3︠
%sage salvus.file("figure4.png")

︡ca1fa52b-4913-46ff-bcff-f1dceceba9d6︡{"once":false,"file":{"show":true,"uuid":"79cf9ed9-5e93-4c75-b6e7-493331b10e54","filename":"figure4.png"}}︡
︠9e4155d2-ff5f-4cb4-8fdd-092b5fb7057d︠
h = figure('visible', 'off');
Dist=((Xrec(2:N,T)-Xrec(1:(N-1),T)));
Prob=(1/N)*Dist.^(-1);
plot(xvalues(2:N,1),Pin);
hold on
Dist=((Xrec(2:N,T)-Xrec(1:(N-1),T)));
Prob=(1/N)*Dist.^(-1);
plot(Xrec(2:N,T),Prob,"r");
saveas(h,"figure5.png");
hold off
︡282c86e8-83ef-4b3a-92af-06526aed7423︡
︠69a8c7aa-3366-4c95-9a42-bc46ea04ccd6︠
%sage salvus.file("figure5.png")
︡f2dcb86b-9eb0-4c7b-a23d-e33797ecf314︡{"once":false,"file":{"show":true,"uuid":"2a0e0d59-769a-4e52-9c62-29900340bf77","filename":"figure5.png"}}︡
︠5dec0c47-64dd-4c8d-b681-cc5f36562c79︠
figure("visible","off");
moviename="MIW1Dv4.mp4";
movie("init",moviename)
for Tsamp=1:10:T
Dist=((Xrec(2:N,Tsamp)-Xrec(1:(N-1),Tsamp)));
Prob=Dist.^(-1);
plot(Xrec(2:N,Tsamp),Prob);
xlim([-20,20]); ylim([0,20]);
movie("add",moviename);
endfor
movie("close",moviename,4); %last arg is frame rate
T
︡b0600b56-f7eb-4a00-aa88-85e165a236f8︡{"stdout":"T = 240"}︡
︠62ad3b8b-79ec-4e4c-9c61-d6d6373f07c5︠
%sage salvus.file("MIW1Dv4.mp4")
︡09d2ab21-444c-4483-a1f6-4d8ef01395f9︡{"once":false,"file":{"show":true,"uuid":"94abd44c-7212-4ffb-92f2-30a0bd6730e4","filename":"MIW1Dv4.mp4"}}︡
︠b1a792c7-4104-44ed-9547-d9f38e65eace︠
︡b646d721-6d75-414a-a666-5284c5906a21︡
︠91caecbe-0432-48e7-9aff-7cd2cb963fea︠









